@@ -167,8 +167,31 @@ main (gint argc, gchar **argv)
 	ChamplainMarkerLayer *layer;
 	VoiceInfo *voiceinfo;	
 	GpsCallbackData callback_data;
+	GstElement *src, *conv, *enc, *muxer, *sink, *pipeline;
 	/* OscilloscopeCallbackData oscilloscope_data; */
 	/* VOSCWindow *vosc; */
+	GMainLoop *main_loops;
+	gchar *filename;
+
+	gst_init(&argc, &argv);
+	gst_init(NULL, NULL);
+	pipeline = gst_pipeline_new("record_pipe");
+
+	src = gst_element_factory_make("autoaudiosrc", "auto_source");
+	conv = gst_element_factory_make("audioconvert", "convert");
+	enc = gst_element_factory_make("vorbisenc", "vorbis_enc");
+	muxer = gst_element_factory_make("oggmux", "oggmux");
+	sink = gst_element_factory_make("filesink", "sink");
+	filename = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/GNOME.ogg", NULL);
+	g_object_set(G_OBJECT(sink), "location",
+		     g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/GNOME.ogg", NULL));
+	gst_bin_add_many(GST_BIN(pipeline), src, conv, enc, muxer, sink, NULL);
+	gst_element_link_many(src, conv, enc, muxer, sink, NULL);
+
+	gst_element_set_state(pipeline, GST_STATE_PLAYING);
+	
+	main_loops = g_main_loop_new(NULL, TRUE);
+  
 	if (clutter_init (&argc, &argv) != CLUTTER_INIT_SUCCESS)
 		return 1;
 	/* vosc = (VOSCWindow *)g_new0(VOSCWindow, 1); */
@@ -215,5 +238,7 @@ main (gint argc, gchar **argv)
 	clutter_actor_show (stage);
         /* clutter_actor_show (voice_oscilloscope); */
 	clutter_main ();
+	g_main_loop_run(main_loops);
+
 	return (0);
 }
